""" mxStack - A stack implementation

    (c) Copyright Marc-Andre Lemburg; All Rights Reserved.
    See the documentation for further information on copyrights,
    or contact the author (mal@lemburg.com).
"""
__package_info__ = """
BEGIN PYTHON-PACKAGE-INFO 1.0
Title:			mxStack - a fast stack implementation
Current-Version:	0.3.0
Home-Page:		http://starship.skyport.net/~lemburg/mxStack.html
Primary-Site:		http://starship.skyport.net/~lemburg/mxStack-0.3.0.zip

This package contains a generic and very simple stack implementation
written in C for speed. For full documentation see the home page.
END PYTHON-PACKAGE-INFO
"""
from mxStack import *
from mxStack import __version__
